@@ -6,14 +6,14 @@ geos_ptrn = re.compile(
 
 
 def geosgeometry_str_to_struct(value):
-    '''
+    """
     Parses a geosgeometry string into struct.
 
     Example:
         SRID=5432;POINT(12.0 13.0)
     Returns:
         >> [5432, 12.0, 13.0]
-    '''
+    """
 
     result = geos_ptrn.match(value)
 
@@ -21,7 +21,7 @@ def geosgeometry_str_to_struct(value):
         return None
 
     return {
-        'srid': result.group(1),
-        'x': result.group(2),
-        'y': result.group(3),
+        "srid": result.group(1),
+        "x": result.group(2),
+        "y": result.group(3),
     }
